From a cohort object, this function extracts the tibble of all CCF or binary data for a patient. This is just a faster way to subset a generic call to Data.

CCF(x, p)

Arguments

x

A REVOLVER cohort.

p

The id of a patient in the cohort.

Value

Data for a custom patient.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

CCF(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> # A tibble: 7 × 8
#>   id            variantID is.driver is.clonal cluster    R1    R2    R3
#>   <chr>         <chr>     <lgl>     <lgl>     <chr>   <dbl> <dbl> <dbl>
#> 1 __mut_id_2120 RB1       TRUE      FALSE     1        0     0.92  0   
#> 2 __mut_id_2151 IKZF1     TRUE      FALSE     1        0     0.92  0   
#> 3 __mut_id_2171 KRAS      TRUE      FALSE     1        0     0.93  0   
#> 4 __mut_id_2173 MET       TRUE      TRUE      2        0.99  0.98  0.99
#> 5 __mut_id_2236 TERT      TRUE      TRUE      2        0.99  0.98  0.99
#> 6 __mut_id_2333 NF1       TRUE      FALSE     5        0.78  0     0   
#> 7 __mut_id_2351 EP300     TRUE      FALSE     6        0.96  0.03  0.98

CCF(TRACERx_NEJM_2017_REVOLVER, 'CRUK0008')
#> # A tibble: 6 × 7
#>   id            variantID is.driver is.clonal cluster    R1    R2
#>   <chr>         <chr>     <lgl>     <lgl>     <chr>   <dbl> <dbl>
#> 1 __mut_id_6744 KEAP1     TRUE      TRUE      2        0.99     1
#> 2 __mut_id_6746 STK11     TRUE      TRUE      2        0.99     1
#> 3 __mut_id_6753 PRDM1     TRUE      TRUE      2        0.99     1
#> 4 __mut_id_6861 U2AF1     TRUE      TRUE      2        0.99     1
#> 5 __mut_id_6886 MYC       TRUE      TRUE      2        0.99     1
#> 6 __mut_id_6916 ARID2     TRUE      FALSE     3        0.86     0