From a cohort object, this function extracts a tibble of all clusters in the data of a patient.

CCF_clusters(x, p)

Arguments

x

A REVOLVER cohort.

p

The id of a patient in the cohort.

Value

CCF or binary clusters data for a custom patient.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

CCF_clusters(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> # A tibble: 4 × 7
#>   cluster nMuts is.driver is.clonal    R1    R2    R3
#>   <chr>   <int> <lgl>     <lgl>     <dbl> <dbl> <dbl>
#> 1 1           3 TRUE      FALSE      0     0.92  0   
#> 2 2           2 TRUE      TRUE       0.99  0.98  0.99
#> 3 5           1 TRUE      FALSE      0.78  0     0   
#> 4 6           1 TRUE      FALSE      0.96  0.03  0.98

CCF_clusters(TRACERx_NEJM_2017_REVOLVER, 'CRUK0008')
#> # A tibble: 2 × 6
#>   cluster nMuts is.driver is.clonal    R1    R2
#>   <chr>   <int> <lgl>     <lgl>     <dbl> <dbl>
#> 1 2           5 TRUE      TRUE       0.99     1
#> 2 3           1 TRUE      FALSE      0.86     0