From a cohort object, this function return the id of the clonal cluster for a patient.

Clonal_cluster(x, p)

Arguments

x

A REVOLVER cohort.

p

The id of a patient in the cohort.

Value

The id of the clonal cluster for the patient.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

Clonal_cluster(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> [1] "2"

Clonal_cluster(TRACERx_NEJM_2017_REVOLVER, 'CRUK0008')
#> [1] "2"