From a cohort object, this function extracts a vector of the sample ids available for a patient.
Samples(x, p)Sample names for a custom patient.
Other Getters:
CCF(),
CCF_clusters(),
Clonal_cluster(),
Data(),
Drivers(),
ITransfer(),
Phylo(),
Subclonal(),
Truncal(),
get_features()
# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')
Samples(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> [1] "R1" "R2" "R3"
Samples(TRACERx_NEJM_2017_REVOLVER, 'CRUK0008')
#> [1] "R1" "R2"