Returns the number of clonal and subclonal occurrences of the drivers in the cohort, and their percentage relative to the cohort size. The function can be run on a subset of drivers.

Stats_drivers(x, drivers = x$variantIDs.driver)

Arguments

x

A REVOLVER cohort.

drivers

The drivers for which the summaries are computed.

Value

A tibble with the driver stastics.

See also

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

# Get the stats for all patients
Stats_drivers(TRACERx_NEJM_2017_REVOLVER)
#> # A tibble: 79 × 7
#>    variantID numClonal p_clonal numSubclonal p_subclonal N_tot  p_tot
#>    <chr>         <dbl>    <dbl>        <dbl>       <dbl> <dbl>  <dbl>
#>  1 TP53             53   0.535             3      0.0303    56 0.566 
#>  2 KRAS             24   0.242             4      0.0404    28 0.283 
#>  3 EGFR             21   0.212             1      0.0101    22 0.222 
#>  4 PIK3CA           20   0.202             1      0.0101    21 0.212 
#>  5 CDKN2A           14   0.141             0      0         14 0.141 
#>  6 SOX2             14   0.141             0      0         14 0.141 
#>  7 KEAP1            12   0.121             0      0         12 0.121 
#>  8 TERT             11   0.111             2      0.0202    13 0.131 
#>  9 FGFR1             9   0.0909            0      0          9 0.0909
#> 10 STK11             8   0.0808            0      0          8 0.0808
#> # ℹ 69 more rows

# And subset the patients
Stats_drivers(TRACERx_NEJM_2017_REVOLVER, drivers = c('TP53', 'KRAS'))
#> # A tibble: 2 × 7
#>   variantID numClonal p_clonal numSubclonal p_subclonal N_tot p_tot
#>   <chr>         <dbl>    <dbl>        <dbl>       <dbl> <dbl> <dbl>
#> 1 TP53             53    0.535            3      0.0303    56 0.566
#> 2 KRAS             24    0.242            4      0.0404    28 0.283