ColorRamp palette extrapolating YlGnBu palette of
RColorBrewer package. The original YlGnBu palette is
sampled for 9 colours.
gradient_palette(n = NULL)Either a function that applied to a number returns the required colours, or the actual sampling function.
Other Plotting functions:
distinct_palette_few(),
distinct_palette_many(),
plot_DET_index(),
plot_clusters(),
plot_dendrogram(),
plot_drivers_clonality(),
plot_drivers_graph(),
plot_drivers_occurrence(),
plot_jackknife_cluster_stability(),
plot_jackknife_coclustering(),
plot_jackknife_trajectories_stability(),
plot_patient_CCF_histogram(),
plot_patient_data(),
plot_patient_mutation_burden(),
plot_patient_oncoprint(),
plot_patient_trees_scores()
gradient_palette(2)
#> [1] "#FFFFD9" "#081D58"