Summary scatterplot of a cohort's fits.

# S3 method for class 'rev_cohort_fit'
plot(x, ...)

Arguments

x

A REVOLVER cohort with fits.

...

Standard S3 signature.

Value

A ggplot object of the plot.

Details

Returns a scatterplot of the penalty of a patient's best fit, versus the tumour mutational burden. Each dot is sized by the number of combinations of Information Transfer for a patient, and coloured by the number of annotated drivers.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

plot(TRACERx_NEJM_2017_REVOLVER)