Plot the dendrogram of REVOLVER"s clusters, where leaves are patient ids, coloured by cluster.

plot_dendrogram(x, cluster_palette = distinct_palette_few)

Arguments

x

A REVOLVER object with fits and clusters.

cluster_palette

A palette function that should return the colour of an arbitrary number of clusters.

Value

A ggplot plot.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

plot_dendrogram(TRACERx_NEJM_2017_REVOLVER)
#> Warning: No shared levels found between `names(values)` of the manual scale and the
#> data's colour values.