R/plot_jackknife_cluster_stability.R
plot_jackknife_cluster_stability.RdThis function plots a barplot of the patients' jackknife cluster staability.
The input vactor to this function can be obtained via Jackknife_cluster_stability;
in the visualisation the clusters are ordered by staability.
plot_jackknife_cluster_stability(x, cluster_palette = distinct_palette_few)A ggplot figure.
Other Plotting functions:
distinct_palette_few(),
distinct_palette_many(),
gradient_palette(),
plot_DET_index(),
plot_clusters(),
plot_dendrogram(),
plot_drivers_clonality(),
plot_drivers_graph(),
plot_drivers_occurrence(),
plot_jackknife_coclustering(),
plot_jackknife_trajectories_stability(),
plot_patient_CCF_histogram(),
plot_patient_data(),
plot_patient_mutation_burden(),
plot_patient_oncoprint(),
plot_patient_trees_scores()
# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')
plot_jackknife_cluster_stability(TRACERx_NEJM_2017_REVOLVER)