This function plots a raster of the patients' jackknife co-clustering probability.

The input matrix to this function can be obtained via Jackknife_patient_coclustering; in the visualisation the patient ids are coloured and ordered according to the clusters in the input dataset, which can be obtained via Cluster.

plot_jackknife_coclustering(x, cluster_palette = distinct_palette_few)

Arguments

x

A REVOLVER cohort with fits, clusters and jackknife results available.

cluster_palette

A palette of colours; must be a function that when applied to a number it returns that number of colours.

Value

A ggplot figure.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

plot_jackknife_coclustering(TRACERx_NEJM_2017_REVOLVER)