This function plots a raster of the patients' jackknife co-clustering probability.

The input matrix to this function can be obtained via Jackknife_patient_coclustering; in the visualisation the patient ids are coloured and ordered according to the clusters in the input dataset, which can be obtained via Cluster.

plot_jackknife_trajectories_stability(
  x,
  annotate_probability = 0.9,
  annotate_percentage = 0.2
)

Arguments

x

A REVOLVER cohort with fits, clusters and jackknife results available.

annotate_probability

Probability threshold above which trajectories are annotated.

annotate_percentage

Percentage threshold above which trajectories are annotated.

Value

A ggplot figure.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

plot_jackknife_trajectories_stability(TRACERx_NEJM_2017_REVOLVER)