This function creates a scatterplot of a full cohort annotating clonal versus subclonal mutational burden, colouring each point by the number of total drivers in the patient, and using as shape the number of clones with drivers.

plot_patient_mutation_burden(x, patient, ...)

Arguments

x

A REVOLVER cohort object.

patient

A patient id.

...

Extra parameters, not used.

Value

A ggplot plot.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')
 
plot_patient_mutation_burden(TRACERx_NEJM_2017_REVOLVER, 'CRUK0001')
#> Warning: log-10 transformation introduced infinite values.
#> Warning: log-10 transformation introduced infinite values.
#> Warning: Removed 54 rows containing non-finite outside the scale range
#> (`stat_density2d()`).

plot_patient_mutation_burden(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> Warning: log-10 transformation introduced infinite values.
#> Warning: log-10 transformation introduced infinite values.
#> Warning: Removed 54 rows containing non-finite outside the scale range
#> (`stat_density2d()`).