Plots a barplot where each tree is a bar, with height proportional to the tree score and colour to its particular combination of transfer.

plot_patient_trees_scores(
  x,
  patient,
  transfer_palette = distinct_palette_few,
  ...
)

Arguments

x

A REVOLVER object.

patient

The id of a patient.

transfer_palette

A function that can be used to sample an arbitrary number of colours to identify the transfers.

...

Extra parameters (currently unused).

Value

A ggplot plot.

Examples

# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')

plot_patient_trees_scores(TRACERx_NEJM_2017_REVOLVER, 'CRUK0001')

plot_patient_trees_scores(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')