From a cohort object, this function return the id of the clonal cluster for a patient.
Clonal_cluster(x, p)The id of the clonal cluster for the patient.
Other Getters:
CCF(),
CCF_clusters(),
Data(),
Drivers(),
ITransfer(),
Phylo(),
Samples(),
Subclonal(),
Truncal(),
get_features()
# Data released in the 'evoverse.datasets'
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')
Clonal_cluster(TRACERx_NEJM_2017_REVOLVER, 'CRUK0002')
#> [1] "2"
Clonal_cluster(TRACERx_NEJM_2017_REVOLVER, 'CRUK0008')
#> [1] "2"