R/compute_mutation_trees.R
compute_mutation_trees.RdCreate mutation tree phylogenies from the package
mtree, fitting the input data given to REVOLVER.
A set of patient ids can be given as input, by default all are
used. A parameter controls if you want to overwrite the trees
of the patient, where they already computed. Please refer to the
parameters of the mtree constructor from package mtree
for the input parameters that you can use to tune the construction.
compute_mutation_trees(
x,
patients = Stats_cohort(x) %>% pull(patientID),
overwrite = FALSE,
...
)A REVOLVER cohort with mutation tree phylogenies for the
requested patients.
Other Cohort creation:
CCF_parser(),
compute_clone_trees(),
input_custom_trees(),
revolver_check_cohort(),
revolver_cohort()
if (FALSE) { # \dontrun{
data('TRACERx_NEJM_2017_REVOLVER', package = 'evoverse.datasets')
x = compute_mutation_trees(TRACERx_NEJM_2017_REVOLVER)
} # }